import type { FC } from 'react'
import { Outlet } from 'react-router-dom'
import React, { useState } from 'react'
import { useNavigate } from "react-router-dom";
import {
  MenuFoldOutlined,
  MenuUnfoldOutlined,
  UploadOutlined,
  UserOutlined,
  UngroupOutlined,
  VideoCameraOutlined
} from '@ant-design/icons'
import css from './workbench.module.scss'
import { Layout, Menu, Button, theme, Breadcrumb } from 'antd'
const items = [
  {
    key: '/workbench/user',
    icon: <UserOutlined />,
    label: '用户管理'
  },
  {
    key: '/workbench/role',
    icon: <UngroupOutlined />,
    label: '角色管理'
  }
]
const { Header, Sider, Content } = Layout

export const Workbench: FC = () => {
  const navigate = useNavigate()
  const [collapsed, setCollapsed] = useState(false)
  const [breadcrumbLabel, setBreadcrumbLabel] = useState('用户管理')
  const {
    token: { colorBgContainer, borderRadiusLG }
  } = theme.useToken()
  const onMenuSelect = ({key}:any) => {
    const item = items.find(i => i.key == key)
    setBreadcrumbLabel(item?.label || '')
    navigate(key)
  }
  return (
    <Layout style={{ minHeight: '100%' }}>
      <Sider trigger={null} collapsible collapsed={collapsed}>
        <div className={css['demo-logo-vertical']} />
        <Menu
          theme="dark"
          mode="inline"
          onSelect={onMenuSelect}
          defaultSelectedKeys={['/workbench/user']}
          items={items}
        />
      </Sider>
      <Layout>
        <Header style={{ padding: 0, background: colorBgContainer }}>
          <div
            style={{
              display: 'flex',
              flexDirection: 'row',
              alignContent: 'center',
              alignItems: 'center'
            }}
          >
            <Button
              type="text"
              icon={collapsed ? <MenuUnfoldOutlined /> : <MenuFoldOutlined />}
              onClick={() => setCollapsed(!collapsed)}
              style={{
                fontSize: '16px',
                width: 64,
                height: 64
              }}
            />
            <Breadcrumb style={{ margin: '16px 0' }} items={[{title: '工作台'}, {title: breadcrumbLabel}]} />
          </div>
        </Header>
        <Content
          style={{
            margin: '24px 16px',
            minHeight: 280,
            borderRadius: borderRadiusLG
          }}
        >
          <Outlet />
        </Content>
      </Layout>
    </Layout>
  )
}

export const Component = Workbench
